@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
-__version__ = '0.5.4'
+__version__ = '0.5.5'
 __author__ = 'Steven Loria'
 __license__ = "MIT"
 
 from marshmallow.serializer import Serializer
 
 from marshmallow.utils import pprint
+
+__all__ = [
+    'Serializer',
+    'pprint'
+]
