@@ -16,6 +16,36 @@ from marshmallow.compat import (text_type, OrderedDict, iteritems, total_seconds
                                 basestring)
 from marshmallow.exceptions import MarshallingError
 
+__all__ = [
+    'validated',
+    'Marshaller',
+    'Raw',
+    'Nested',
+    'List',
+    'String',
+    'UUID',
+    'Number',
+    'Integer',
+    'Boolean',
+    'FormattedString',
+    'Float',
+    'Arbitrary',
+    'DateTime',
+    'LocalDateTime',
+    'Time',
+    'Date',
+    'TimeDelta',
+    'Fixed',
+    'ZERO',
+    'Price',
+    'Url',
+    'Email',
+    'Method',
+    'Function',
+    'Select',
+    'Enum',
+]
+
 
 def validated(f):
     """Decorator that wraps a field's ``format`` or ``output`` method. If an
@@ -44,13 +74,13 @@ def validated(f):
 
 
 class Marshaller(object):
-    '''Callable class responsible for marshalling data and storing errors.
+    """Callable class responsible for marshalling data and storing errors.
 
     :param str prefix: Optional prefix that will be prepended to all the
         serialized field names.
     :param bool strict: If ``True``, raise errors if invalid data are passed in
         instead of failing silently and storing the errors.
-    '''
+    """
     def __init__(self, prefix='', strict=False):
         self.prefix = prefix
         self.strict = strict
@@ -181,6 +211,9 @@ class Raw(FieldABC):
     def output(self, key, obj):
         """Pulls the value for the given key from the object, applies the
         field's formatting and returns the result.
+
+        :param str key: The attibute or key to get.
+        :param str obj: The object to pull the key from.
         :exception MarshallingError: In case of formatting problem
         """
         value = self.get_value(key, obj)
@@ -196,7 +229,7 @@ class Nested(Raw):
     Examples: ::
 
         user = fields.Nested(UserSerializer)
-        collaborators = fields.Nested(UserSerializer, many=True, only='id')
+        collaborators = fields.Nested(UserSerializer(many=True, only='id'))
         parent = fields.Nested('self')
 
     :param Serializer nested: The Serializer class or instance to nest, or
@@ -655,13 +688,16 @@ class Function(Raw):
 
 
 class Select(Raw):
-    """A field that only lets you set values in the selection.
+    """A field that provides a set of values which an attribute must be
+    contrained to.
 
     :param choices: A list of valid values.
     :param default: Default value for the field if the attribute is not set.
     :param str attribute: The name of the attribute to get the value from. If
         ``None``, assumes the attribute has the same name as the field.
     :param str error: Error message stored upon validation failure.
+
+    :raises: MarshallingError if attribute's value is not one of the given choices.
     """
     def __init__(self,  choices, default=None, attribute=None, error=None, **kwargs):
         self.choices = choices
@@ -669,5 +705,7 @@ class Select(Raw):
 
     def format(self, value):
         if value not in self.choices:
-            raise MarshallingError("'%s' is not a valid choice for this field." % value)
+            raise MarshallingError("{0!r} is not a valid choice for this field.".format(value))
         return value
+
+Enum = Select
