@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''The Serializer class, including its metaclass and options (class Meta).'''
+"""The Serializer class, including its metaclass and options (class Meta)."""
 from __future__ import absolute_import
 import datetime as dt
 import json
@@ -7,6 +7,7 @@ import copy
 import uuid
 import types
 import warnings
+import functools
 
 from marshmallow import base, fields, utils
 from marshmallow.compat import (with_metaclass, iteritems, text_type,
@@ -123,6 +124,8 @@ class BaseSerializer(base.SerializerABC):
         dt.timedelta: fields.TimeDelta,
     }
 
+    OPTIONS_CLASS = SerializerOpts
+
     class Meta(object):
         '''Options object for a Serializer.
 
@@ -161,7 +164,7 @@ class BaseSerializer(base.SerializerABC):
         self.__data = None
         self.obj = obj
         self.many = many
-        self.opts = SerializerOpts(self.Meta)
+        self.opts = self.OPTIONS_CLASS(self.Meta)
         self.only = only or ()
         self.exclude = exclude or ()
         self.prefix = prefix
@@ -177,9 +180,34 @@ class BaseSerializer(base.SerializerABC):
         self._update_fields(obj)
         # If object is passed in, marshal it immediately so that errors are stored
         if self.obj is not None:
-            self.__data = self.marshal(self.obj, self.fields, many=self.many)
+            raw_data = self.marshal(self.obj, self.fields, many=self.many)
             if self.extra:
-                self.__data.update(self.extra)
+                raw_data.update(self.extra)
+            self.__data = self.process_data(raw_data)
+
+    @classmethod
+    def factory(cls, *args, **kwargs):
+        """Create a factory function that returns an instance of the serializer.
+        Can be used to "freeze" the serializer's arguments.
+
+        Example usage: ::
+
+            serialize_user = UserSerializer.factory(strict=True)
+            user = User(email='invalidemail')
+            serialize_user(user)  # => raises MarshallingError
+
+        :param args: Takes the same positional and keyword arguments as the
+            serializer's constructor
+        :rtype: A ``functools.partial`` object (from the standard library)
+        :return: A function that returns instances of the serializer, fixed with
+            the passed arguments.
+
+        .. versionadded:: 0.5.5
+
+        """
+        factory_func = functools.partial(cls, *args, **kwargs)
+        functools.update_wrapper(factory_func, cls)
+        return factory_func
 
     def _update_fields(self, obj):
         """Update fields based on the passed in object."""
@@ -262,12 +290,13 @@ class BaseSerializer(base.SerializerABC):
 
     @property
     def data(self):
-        '''The serialized data as an ``OrderedDict``.
-        '''
+        """The serialized data as an :class:`OrderedDict`.
+        """
         if not self.__data:  # Cache the data
-            self.__data = self.marshal(self.obj, self.fields, many=self.many)
+            raw_data = self.marshal(self.obj, self.fields, many=self.many)
             if self.extra:
-                self.__data.update(self.extra)
+                raw_data.update(self.extra)
+            self.__data = self.process_data(raw_data)
         return self.__data
 
     @property
@@ -280,6 +309,13 @@ class BaseSerializer(base.SerializerABC):
         """Dictionary of errors raised during serialization."""
         return self.marshal.errors
 
+    def process_data(self, data):
+        """Hook that allows subclasses to modify the final output of the data.
+
+        .. versionadded:: 0.5.5
+        """
+        return data
+
     def to_json(self, *args, **kwargs):
         '''Return the JSON representation of the data. Takes the same arguments
         as Pythons built-in ``json.dumps``.
